==> qtjambi-qt3dcore-5.15.14-sources.jar: io/qt/qt3d/core/QPropertyUpdatedChange.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Used to notify when a property value is updated</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyupdatedchange.html">Qt3DCore::QPropertyUpdatedChange</a></p>
 */
public class QPropertyUpdatedChange extends io.qt.qt3d.core.QStaticPropertyUpdatedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyupdatedchange.html#QPropertyUpdatedChange">Qt3DCore::QPropertyUpdatedChange::QPropertyUpdatedChange(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    public QPropertyUpdatedChange(io.qt.qt3d.core.@NonNull QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QPropertyUpdatedChange instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyupdatedchange.html#setValue">Qt3DCore::QPropertyUpdatedChange::setValue(QVariant)</a></p>
     */
    @QtUninvokable
    public final void setValue(java.lang.Object value){
        setValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @QtUninvokable
    private native void setValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyupdatedchange.html#value">Qt3DCore::QPropertyUpdatedChange::value()const</a></p>
     */
    @QtUninvokable
    public final java.lang.Object value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.Object value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QPropertyUpdatedChange(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.19-sources.jar: io/qt/qt3d/core/QPropertyUpdatedChange.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Used to notify when a property value is updated</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyupdatedchange.html">Qt3DCore::QPropertyUpdatedChange</a></code></p>
 */
public class QPropertyUpdatedChange extends io.qt.qt3d.core.QStaticPropertyUpdatedChangeBase
{
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyupdatedchange.html#QPropertyUpdatedChange">Qt3DCore::QPropertyUpdatedChange::<wbr/>QPropertyUpdatedChange(Qt3DCore::QNodeId)</a></code></p>
     */
    public QPropertyUpdatedChange(io.qt.qt3d.core.@NonNull QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    private native static void initialize_native(QPropertyUpdatedChange instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyupdatedchange.html#setValue">Qt3DCore::QPropertyUpdatedChange::<wbr/>setValue(QVariant)</a></code></p>
     */
    @QtUninvokable
    public final void setValue(java.lang.Object value){
        setValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @QtUninvokable
    private native void setValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyupdatedchange.html#value">Qt3DCore::QPropertyUpdatedChange::<wbr/>value()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.Object value(){
        return value_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.Object value_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QPropertyUpdatedChange(QPrivateConstructor p) { super(p); } 
    
}
